Dependencies and Credits — symfit 0.3.0 documentation

# Dependencies and Credits

Always pay credit where credit’s due. `symfit` uses the following projects to make it’s sexy interface possible:

- leastsqbound-scipy is used to bound parameters to a given domain.
- seaborn was used to make the beautifully styled plots in the example code. All you have to do to sexify your matplotlib plot’s is import seaborn, even if you don’t use it’s special plotting facilities, so I highly recommend it.
- numpy and scipy are of course used to do efficient data processing.
- sympy is used for the manipulation of the symbolic expressions that give this project it’s high readability.